@@ -19,9 +19,9 @@ class FireWall(object):
 		# do.
 		output = utils.__execute_script__("printf 'y\\ny\\ny\\ny\\ny\\ny\\n' | sudo ufw enable")
 		if "Firewall is active and enabled on system startup" in output:
-			return r3sponse.success(f"Successfully enabled the firewall.")
+			return Response.success(f"Successfully enabled the firewall.")
 		else:
-			return r3sponse.error(f"Failed to enable the firewall.")
+			return Response.error(f"Failed to enable the firewall.")
 
 		#
 	def disable(self):
@@ -33,9 +33,9 @@ class FireWall(object):
 		# do.
 		output = utils.__execute_script__("printf 'y\\ny\\ny\\ny\\ny\\ny\\n' | sudo ufw disable")
 		if "Firewall stopped and disabled on system startup" in output:
-			return r3sponse.success(f"Successfully disabled the firewall.")
+			return Response.success(f"Successfully disabled the firewall.")
 		else:
-			return r3sponse.error(f"Failed to disable the firewall.")
+			return Response.error(f"Failed to disable the firewall.")
 
 		#
 	def allow(self, port):
@@ -48,9 +48,9 @@ class FireWall(object):
 		# do.
 		output = utils.__execute__(["sudo", "ufw", "allow", str(port)])
 		if "Rule updated" in output or "Rules updated" in output or "Skipping adding existing rule" in output:
-			return r3sponse.success(f"Successfully allowed port [{port}].")
+			return Response.success(f"Successfully allowed port [{port}].")
 		else:
-			return r3sponse.error(f"Failed to allow port [{port}], output: [{output}].")
+			return Response.error(f"Failed to allow port [{port}], output: [{output}].")
 
 		#
 	def deny(self, port):
@@ -63,9 +63,9 @@ class FireWall(object):
 		# do.
 		output = utils.__execute__(["sudo", "ufw", "deny", str(port)])
 		if "Rule updated" in output or "Rules updated" in output or "Skipping adding existing rule" in output:
-			return r3sponse.success(f"Successfully denied port [{port}].")
+			return Response.success(f"Successfully denied port [{port}].")
 		else:
-			return r3sponse.error(f"Failed to deny port [{port}], output: [{output}].")
+			return Response.error(f"Failed to deny port [{port}], output: [{output}].")
 
 		#
 	def allow_all(self):
@@ -77,7 +77,7 @@ class FireWall(object):
 		for port, info in ports.items():
 			response = self.allow(port)
 			if response["error"] != None: return response
-		return r3sponse.success(f"Successfully allowed all {len(ports)} ports.")
+		return Response.success(f"Successfully allowed all {len(ports)} ports.")
 	def deny_all(self):
 		response = self.info()
 		if response["error"] != None: return response
@@ -87,7 +87,7 @@ class FireWall(object):
 		for port, info in ports.items():
 			response = self.allow(port)
 			if response["error"] != None: return response
-		return r3sponse.success(f"Successfully allowed all {len(ports)} ports.")
+		return Response.success(f"Successfully allowed all {len(ports)} ports.")
 	def set_default(self, deny=True):
 		
 
@@ -101,9 +101,9 @@ class FireWall(object):
 		else: option = "allow"
 		output = utils.__execute__(["sudo", "ufw", "default", option])
 		if "Default incoming policy changed to " in output:
-			return r3sponse.success(f"Successfully set the default action to [{option}].")
+			return Response.success(f"Successfully set the default action to [{option}].")
 		else:
-			return r3sponse.error(f"Failed set the default action to [{option}].")
+			return Response.error(f"Failed set the default action to [{option}].")
 
 		#
 	def info(self):
@@ -155,7 +155,7 @@ class FireWall(object):
 				c += 1
 
 		# success.
-		return r3sponse.success("Successfully retrieved the firewall info.", {
+		return Response.success("Successfully retrieved the firewall info.", {
 			"status":status,
 			"ports":ports,
 		})
@@ -164,8 +164,8 @@ class FireWall(object):
 	# system functions.
 	def __check_os__(self):
 		if OS not in ["linux"]:
-			return r3sponse.error(f"Unsupported operating system: [{OS}].")
-		return r3sponse.success(f"Supported operating system: [{OS}].")
+			return Response.error(f"Unsupported operating system: [{OS}].")
+		return Response.success(f"Supported operating system: [{OS}].")
 
 # initialized classes.
 firewall = FireWall()
